:py:mod:`simplemseed`
=====================

.. py:module:: simplemseed

.. autodoc2-docstring:: simplemseed
   :allowtitles:

Submodules
----------

.. toctree::
   :titlesonly:
   :maxdepth: 1

   simplemseed.exceptions
   simplemseed.fdsnsourceid
   simplemseed.miniseed
   simplemseed.mseed2to3
   simplemseed.mseed3
   simplemseed.mseed3details
   simplemseed.mseed3merge
   simplemseed.seedcodec
   simplemseed.steim1
   simplemseed.steim2
   simplemseed.steimframeblock

Package Contents
----------------

Data
~~~~

.. list-table::
   :class: autosummary longtable
   :align: left

   * - :py:obj:`__all__ <simplemseed.__all__>`
     - .. autodoc2-docstring:: simplemseed.__all__
          :summary:
   * - :py:obj:`__version__ <simplemseed.__version__>`
     - .. autodoc2-docstring:: simplemseed.__version__
          :summary:

API
~~~

.. py:data:: __all__
   :canonical: simplemseed.__all__
   :value: ['MiniseedHeader', 'MiniseedRecord', 'MiniseedException', 'unpackMiniseedHeader', 'unpackMiniseedRec...

   .. autodoc2-docstring:: simplemseed.__all__

.. py:data:: __version__
   :canonical: simplemseed.__version__
   :value: '0.3.0'

   .. autodoc2-docstring:: simplemseed.__version__
